synquill_utils
library
Classes
Indexed
Annotation to mark a field for database indexing.
This will create a database index on the annotated field to improve
query performance.
ManyToOne
Annotation to mark a field as a many-to-one relation.
This creates a foreign key constraint in the database.
OneToMany
Annotation to mark a field as a one-to-many relation.
This field should be of type List<T> where T is the related model.
PluralizationUtils
Utility class for English pluralization rules
SynquillDatabaseVersion
Annotation to specify the database schema version.
This annotation can be placed anywhere in the application code where
SynquillStorage is initialized. If no annotation is present, the default
version is 1.
SynquillRepository
An annotation to mark a class as a data model for which
a Drift table and repository should be generated.